@@ -53,7 +53,7 @@ import static com.openexchange.publish.json.PublicationJSONErrorMessage.THROWABL
 import java.io.IOException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
 import com.openexchange.ajax.PermissionServlet;
 import com.openexchange.ajax.container.Response;
 import com.openexchange.exception.OXException;
@@ -68,6 +68,8 @@ import com.openexchange.tools.session.ServerSession;
  */
 public abstract class AbstractPublicationServlet extends PermissionServlet {
 
+    private static final long serialVersionUID = 5880236559668102629L;
+
     /**
      * Initializes a new {@link AbstractPublicationServlet}.
      */
@@ -81,7 +83,7 @@ public abstract class AbstractPublicationServlet extends PermissionServlet {
     }
 
     protected void writeOXException(final OXException x, final HttpServletRequest req, final HttpServletResponse resp) {
-        x.log(com.openexchange.exception.Log.valueOf(getLog()));
+        x.log(getLog());
         final Response response = new Response(getSessionObject(req));
         response.setException(x);
         writeResponseSafely(response, resp, getSessionObject(req));
@@ -102,9 +104,9 @@ public abstract class AbstractPublicationServlet extends PermissionServlet {
         try {
             writeResponse(response, resp, session);
         } catch (final IOException e) {
-            getLog().error(e.getMessage(), e);
+            getLog().error("", e);
         }
     }
 
-    protected abstract Log getLog();
+    protected abstract Logger getLog();
 }
