@@ -61,9 +61,10 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.TimeZone;
+import java.util.concurrent.ConcurrentHashMap;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-import org.apache.commons.logging.Log;
+import com.openexchange.ajax.AJAXUtility;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.contact.ContactService;
 import com.openexchange.exception.OXException;
@@ -73,7 +74,6 @@ import com.openexchange.groupware.ldap.User;
 import com.openexchange.html.HtmlService;
 import com.openexchange.java.AllocatingStringWriter;
 import com.openexchange.java.Strings;
-import com.openexchange.log.LogFactory;
 import com.openexchange.osgi.ExceptionUtils;
 import com.openexchange.publish.Publication;
 import com.openexchange.publish.PublicationDataLoaderService;
@@ -95,44 +95,36 @@ public class MicroformatServlet extends OnlinePublicationServlet {
 
     private static final Map<String, OXMFPublicationService> publishers = new HashMap<String, OXMFPublicationService>();
 
-    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(MicroformatServlet.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(MicroformatServlet.class);
 
-    private static final String MODULE = "module";
+    private static final String MODULE = OXMFConstants.MODULE;
 
-    private static final String SITE = "site";
+    private static final String SITE = OXMFConstants.SITE;
 
-    private static final String CONTEXTID = "ctx";
+    private static final String CONTEXTID = OXMFConstants.CONTEXTID;
 
-    private static final String USE_WHITELISTING_PROPERTY_NAME = "com.openexchange.publish.microformats.usesWhitelisting";
+    private static final String SITE_NAME = OXMFConstants.SITE_NAME;
 
-    private static PublicationDataLoaderService dataLoader = null;
-
-    private static Map<String, Map<String, Object>> additionalTemplateVariables = new HashMap<String, Map<String, Object>>();
-
-    private static volatile UserService userService;
-
-    private static volatile StringTranslator translator;
-
-    private static volatile ConfigurationService configService;
-
-    private static volatile ContactService contacts;
-
-    public static volatile HtmlService htmlService;
+    /**
+     * Property to get the configured name of the hoster to be displayed in disclaimer of the default template
+     */
+    private static final String PROPERTY_LEGAL_HOSTER_NAME = "com.openexchange.publish.legalHosterName";
 
     private static final DateFormat DATE_FORMAT = new SimpleDateFormat("yyyy-MM-dd");
+    private static final DateFormat TIME_FORMAT = new SimpleDateFormat("yyyy-MM-dd H:m:s.S z");
     static {
         DATE_FORMAT.setTimeZone(TimeZone.getTimeZone("UTC"));
-    }
-
-    private static final DateFormat TIME_FORMAT = new SimpleDateFormat("yyyy-MM-dd H:m:s.S z");
-
-    static {
         TIME_FORMAT.setTimeZone(TimeZone.getTimeZone("UTC"));
     }
 
-    public MicroformatServlet() {
-        super();
-    }
+    private static final Map<String, Map<String, Object>> ADDITONAL_TEMPLATE_VARIABLES = new ConcurrentHashMap<String, Map<String, Object>>();
+
+    private static volatile PublicationDataLoaderService dataLoader = null;
+    private static volatile UserService userService;
+    private static volatile StringTranslator translator;
+    private static volatile ConfigurationService configService;
+    private static volatile ContactService contacts;
+    public static volatile HtmlService htmlService;
 
     public static void setPublicationDataLoaderService(final PublicationDataLoaderService service) {
         dataLoader = service;
@@ -152,7 +144,7 @@ public class MicroformatServlet extends OnlinePublicationServlet {
 
     public static void registerType(final String module, final OXMFPublicationService publisher, final Map<String, Object> additionalVars) {
         publishers.put(module, publisher);
-        additionalTemplateVariables.put(module, additionalVars);
+        ADDITONAL_TEMPLATE_VARIABLES.put(module, additionalVars);
     }
 
     public static void setContactService(final ContactService service) {
@@ -163,6 +155,15 @@ public class MicroformatServlet extends OnlinePublicationServlet {
         htmlService = htmlService2;
     }
 
+    // ----------------------------------------------------------------------------------------------------------------- //
+
+    /**
+     * Initializes a new {@link MicroformatServlet}.
+     */
+    public MicroformatServlet() {
+        super();
+    }
+
     @Override
     protected void service(final HttpServletRequest req, final HttpServletResponse resp) throws IOException {
         try {
@@ -201,22 +202,32 @@ public class MicroformatServlet extends OnlinePublicationServlet {
             final User user = getUser(publication);
             final Contact userContact = getContact(new PublicationSession(publication), publication.getContext());
 
+            // Sanitize publication
+            sanitizePublication(publication);
+
+            // Compose variables for template processing
             variables.put(getCollectionName(module), loaded);
             variables.put("publication", publication);
             variables.put("request", req);
             variables.put("dateFormat", DATE_FORMAT);
             variables.put("timeFormat", TIME_FORMAT);
-            String admin = configService.getProperty("PUBLISH_REVOKE");
-            if (admin == null || admin.equals("")) {
-                admin = userService.getUser(ctx.getMailadmin(), ctx).getMail();
+            {
+                String admin = configService.getProperty("PUBLISH_REVOKE");
+                if (admin == null || admin.equals("")) {
+                    admin = userService.getUser(ctx.getMailadmin(), ctx).getMail();
+                }
+                String legalHosterName = configService.getProperty(MicroformatServlet.PROPERTY_LEGAL_HOSTER_NAME);
+                if (legalHosterName == null || legalHosterName.equals("")) {
+                    legalHosterName = MicroformatStrings.DISCLAIMER_ALTERNATIV_HOSTER_NAME_WORDING;
+                }
+                String privacyText = formatPrivacyText(getPrivacyText(user), legalHosterName, admin, user, new Date(publication.getCreated()));
+                variables.put("privacy", privacyText); // TODO Use lastmodified once someone implements this.
             }
-            final String privacyText = formatPrivacyText(getPrivacyText(user), admin, user, new Date());
-            variables.put("privacy", privacyText); // TODO Use lastmodified once someone implements this.
             variables.put("userContact", userContact);
             variables.put("htmlService", new HTMLUtils(htmlService));
 
-            if (additionalTemplateVariables.containsKey(module)) {
-                variables.putAll(additionalTemplateVariables.get(module));
+            if (ADDITONAL_TEMPLATE_VARIABLES.containsKey(module)) {
+                variables.putAll(ADDITONAL_TEMPLATE_VARIABLES.get(module));
             }
 
             final OXTemplate template = publisher.loadTemplate(publication);
@@ -231,26 +242,34 @@ public class MicroformatServlet extends OnlinePublicationServlet {
             writer.write(html);
             writer.flush();
         } catch (final OXException x) {
-            LOG.error(x.getMessage(), x);
+            LOG.error("", x);
             final PrintWriter writer = resp.getWriter();
             writer.println("Publishing failed. Please try again later. Exception ID: " + x.getExceptionId());
             writer.flush();
         } catch (final Throwable t) {
             ExceptionUtils.handleThrowable(t);
-            LOG.error(t.getMessage(), t);
+            LOG.error("", t);
             final PrintWriter writer = resp.getWriter();
             writer.println("Publishing failed. Please try again later.");
             writer.flush();
         }
     }
 
+    private void sanitizePublication(final Publication publication) {
+        Map<String, Object> configuration = publication.getConfiguration();
+        Object siteObj = configuration.get(SITE_NAME);
+        if (null != siteObj) {
+            configuration.put(SITE_NAME, saneSiteName(siteObj.toString()));
+        }
+    }
+
     private Contact getContact(final PublicationSession publicationSession, final Context context) throws OXException {
         return contacts.getUser(publicationSession, publicationSession.getUserId());
     }
 
-    private String formatPrivacyText(final String privacyText, final String adminAddress, final User user, final Date creationDate) {
+    private String formatPrivacyText(final String privacyText, final String company, final String adminAddress, final User user, final Date creationDate) {
         final String date = new SimpleDateFormat("yyyy-MM-dd").format(creationDate);
-        final String retVal = String.format(privacyText, adminAddress, user.getMail(), date);
+        final String retVal = String.format(privacyText, company, adminAddress, user.getMail(), date);
         return "<p>" + retVal.replaceAll("\n", "</p><p>") + "</p>";
     }
 
@@ -287,4 +306,11 @@ public class MicroformatServlet extends OnlinePublicationServlet {
         return translator.translate(user.getLocale(), MicroformatStrings.DISCLAIMER_PRIVACY);
     }
 
+    private String saneSiteName(final String site) {
+        if (Strings.isEmpty(site)) {
+            return site;
+        }
+        return AJAXUtility.encodeUrl(site, true, false);
+    }
+
 }
